ReplayOrigin class final

Served by RecorderInterceptor from a recording session.

Inheritance

Constructors

ReplayOrigin({required DateTime? recordedAt})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
recordedAt DateTime?
When the replayed interaction was originally captured, or null when the replay header carries a value that is not a timestamp.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited