recordedAt property

DateTime? recordedAt
final

When the replayed interaction was originally captured, or null when the replay header carries a value that is not a timestamp.

Implementation

final DateTime? recordedAt;