recordedAt property
When the replayed interaction was originally captured, or null when
the replay header carries a value that is not a timestamp.
Implementation
final DateTime? recordedAt;
When the replayed interaction was originally captured, or null when
the replay header carries a value that is not a timestamp.
final DateTime? recordedAt;